[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]

[tor-commits] [doctor/master] Drop StaleDesc notifications



commit 757608cb25217831d044dd7d8291ea3fc83f1da3
Author: Damian Johnson <atagar@xxxxxxxxxxxxxx>
Date:   Mon Dec 17 10:53:30 2018 -0800

    Drop StaleDesc notifications
    
    Only moria1 votes on the new flag. Treating it in the same way as BadExit...
    
      https://lists.torproject.org/pipermail/tor-consensus-health/2018-December/009451.html
---
 consensus_health_checker.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/consensus_health_checker.py b/consensus_health_checker.py
index 8a72a82..3d675ca 100755
--- a/consensus_health_checker.py
+++ b/consensus_health_checker.py
@@ -675,11 +675,11 @@ def has_similar_flag_counts(latest_consensus, consensuses, votes):
     for flag, count in flag_count.items():
       # Skipping check for the following flags because...
       #
       #   * BadExit is only voted on by a few authorities.
       #   * Running isn't voted on when an authority first starts up.
       #   * moria1 likes to experiment with the HSDir flag.
 
-      if flag in ('BadExit', 'Running', 'HSDir'):
+      if flag in ('BadExit', 'Running', 'HSDir', 'StaleDesc'):
         continue
 
       vote_count = authority_flag_count.get(flag, 0)
@@ -675,11 +675,11 @@ def has_similar_flag_counts(latest_consensus, consensuses, votes):
       # Skipping check for the following flags because...
       #
-      #   * BadExit is only voted on by a few authorities.
+      #   * BadExit and StaleDesc is only voted on by a few authorities.
       #   * Running isn't voted on when an authority first starts up.
       #   * moria1 likes to experiment with the HSDir flag.

_______________________________________________
tor-commits mailing list
tor-commits@xxxxxxxxxxxxxxxxxxxx
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits